@@ -21,5 +21,5 @@ def write_file(notes: list[Note], file_name: str):
     for note in notes:
         midi.addNote(0, 0, note.pitch, note.start, note.end - note.start, note.velocity)
 
-    with open(f'../midi/{file_name}.mid', "wb") as output_file:
+    with open(f'midi/{file_name}.mid', "wb") as output_file:
         midi.writeFile(output_file)
